@@ -15,7 +15,7 @@ from .scheduled_messages import ScheduledMessages
 from .flow_link_state import FlowStateAssignedToChat
 from ..company.assets.chat_assets import ChattyAIAgentAssignedToChat
 from ..messages.chatty_messages.base.message_draft import MessageDraft
-
+from ..utils.custom_exceptions.custom_exceptions import MissingAIAgentForSmartFollowUp
 from .time_left import TimeLeft
 import json
 import logging
@@ -143,7 +143,7 @@ class Chat(CompanyAssetModel):
     def assigned_chatty_ai_agent(self) -> ChattyAIAgentAssignedToChat:
         """Get the assigned chatty ai agent"""
         if self.chatty_ai_agent is None:
-            raise ValueError(f"Chat {self.id} has no chatty ai agent assigned to it")
+            raise MissingAIAgentForSmartFollowUp(f"Chat {self.id} has no chatty ai agent assigned to it")
         return self.chatty_ai_agent
 
 
